@@ -2,15 +2,15 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
+    http://sourceforge.net/projects/gpredict/
     More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+            http://gpredict.oz9aec.net/
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,28 +30,11 @@
 
 #include <glib.h>
 #include "sgpsdp/sgp4sdp4.h"
+#include "qth-data.h"
 
 
-
-/** \brief QTH data structure in human readable form. */
-typedef struct {
-	gchar    *name;   /*!< Name, eg. callsign. */
-	gchar    *loc;    /*!< Location, eg City, Country. */
-	gchar    *desc;   /*!< Short description. */
-	gdouble   lat;    /*!< Latitude in dec. deg. North. */
-	gdouble   lon;    /*!< Longitude in dec. deg. East. */
-	gint      alt;    /*!< Altitude above sea level in meters. */
-	gchar    *qra;    /*!< QRA locator */
-	gchar    *wx;     /*!< Weather station code (4 chars). */
-
-	GKeyFile *data;   /*!< Raw data from cfg file. */
-} qth_t;
-
-
-gint gtk_sat_data_read_qth (const gchar *filename, qth_t *qth);
-gint gtk_sat_data_save_qth (const gchar *filename, qth_t *qth);
-void gtk_sat_data_free_qth (qth_t *qth);
 gint gtk_sat_data_read_sat (gint catnum, sat_t *sat);
 void gtk_sat_data_init_sat (sat_t *sat, qth_t *qth);
+void gtk_sat_data_copy_sat (const sat_t *source, sat_t *dest, qth_t *qth);
 
 #endif
