@@ -2,15 +2,15 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
+    http://sourceforge.net/projects/gpredict/
     More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+            http://gpredict.oz9aec.net/
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -56,9 +56,9 @@ typedef struct _GtkSkyGlanceClass   GtkSkyGlanceClass;
 
 /** \brief Satellite object on graph. */
 typedef struct {
-	guint              catnum;  /*!< Catalogue number of satellite */
-	pass_t             *pass;    /*!< Details of the corresponding pass. */
-	GooCanvasItemModel *box;     /*!< Canvas item showing the pass */
+    guint              catnum;  /*!< Catalogue number of satellite */
+    pass_t             *pass;    /*!< Details of the corresponding pass. */
+    GooCanvasItemModel *box;     /*!< Canvas item showing the pass */
 } sky_pass_t;
 
 
@@ -68,54 +68,54 @@ typedef struct {
 
 struct _GtkSkyGlance
 {
-	GtkVBox vbox;
+    GtkVBox vbox;
 
-	GtkWidget  *canvas;   /*!< The canvas widget */
+    GtkWidget  *canvas;   /*!< The canvas widget */
 
-	GHashTable *sats;     /*!< Copy of satellites. */
-	qth_t      *qth;      /*!< Pointer to current location. */
+    GHashTable *sats;     /*!< Copy of satellites. */
+    qth_t      *qth;      /*!< Pointer to current location. */
 
-	GSList *passes;      /*!< Canvas items representing each pass.
-						      Each element in the list is of type sky_pass_t.
-						 */
-	GSList *satlab;      /*!< Canvas items showing satellite names. */
+    GSList *passes;      /*!< Canvas items representing each pass.
+                                Each element in the list is of type sky_pass_t.
+                            */
+    GSList *satlab;      /*!< Canvas items showing satellite names. */
 
 
-	guint       x0;       /*!< X0 */
-	guint       y0;       /*!< Y0 */
-	guint       w;        /*!< width of the plot */
-	guint       h;        /*!< height of the plot */
-	guint       pps;      /*!< pixels per satellite */
+    guint       x0;       /*!< X0 */
+    guint       y0;       /*!< Y0 */
+    guint       w;        /*!< width of the plot */
+    guint       h;        /*!< height of the plot */
+    guint       pps;      /*!< pixels per satellite */
 
-	guint       numsat;   /*!< Number of satellites */
-	guint       satcnt;   /*!< Counter to keep track of how many satellites we have
-							   plotted so far when creating the boxes.
-							   This is needed to ensure that we do not plot more
-							   than 10 satellites and to know which colour to fetch
-							   from sat-cfg.
-						  */
-	gdouble     ts,te;    /*!< Start and end times (Julian date) */
+    guint       numsat;   /*!< Number of satellites */
+    guint       satcnt;   /*!< Counter to keep track of how many satellites we have
+                                plotted so far when creating the boxes.
+                                This is needed to ensure that we do not plot more
+                                than 10 satellites and to know which colour to fetch
+                                from sat-cfg.
+                            */
+    gdouble     ts,te;    /*!< Start and end times (Julian date) */
 
-	GSList     *majors;   /*!< Major ticks for every hour */
-	GSList     *minors;   /*!< Minor ticks for every 30 min */
-	GSList     *labels;   /*!< Tick labels for every hour */
-	
-	GooCanvasItemModel *footer;  /*!< Footer area with time ticks and labels */
-	GooCanvasItemModel *axisl;   /*!< Axis label */
-	GooCanvasItemModel *cursor;  /*!< Vertical line tracking the cursor */
-	GooCanvasItemModel *timel;   /*!< Label showing time under cursor */
+    GSList     *majors;   /*!< Major ticks for every hour */
+    GSList     *minors;   /*!< Minor ticks for every 30 min */
+    GSList     *labels;   /*!< Tick labels for every hour */
+
+    GooCanvasItemModel *footer;  /*!< Footer area with time ticks and labels */
+    GooCanvasItemModel *axisl;   /*!< Axis label */
+    GooCanvasItemModel *cursor;  /*!< Vertical line tracking the cursor */
+    GooCanvasItemModel *timel;   /*!< Label showing time under cursor */
 
 };
 
 struct _GtkSkyGlanceClass
 {
-	GtkVBoxClass parent_class;
+    GtkVBoxClass parent_class;
 };
 
 
 
 GtkType        gtk_sky_glance_get_type   (void);
-GtkWidget*     gtk_sky_glance_new        (GHashTable *sats, qth_t *qth);
+GtkWidget*     gtk_sky_glance_new        (GHashTable *sats, qth_t *qth, gdouble ts);
 
 /*
 void           gtk_sky_glance_reconf     (GtkWidget *skg);
