@@ -2,17 +2,17 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
     Parts are Copyright John A. Magliacane, KD2BD 1991-2003 (indicated below)
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
              John A. Magliacane, KD2BD.
 
     Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
+    http://sourceforge.net/projects/gpredict/
     More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+            http://gpredict.oz9aec.net/
  
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
