@@ -2,15 +2,15 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2009  Alexandru Csete, OZ9AEC.
 
-  Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <oz9aec@gmail.com>
 
   Comments, questions and bugreports should be submitted via
-  http://sourceforge.net/projects/groundstation/
+  http://sourceforge.net/projects/gpredict/
   More details can be found at the project home page:
 
-  http://groundstation.sourceforge.net/
+  http://gpredict.oz9aec.net/
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,11 +34,12 @@
 #include "gpredict-utils.h"
 #include "sat-cfg.h"
 #include "sat-log.h"
-#include "gtk-sat-data.h"
+#include "qth-data.h"
 #include "sat-pref-qth.h"
 #include "sat-pref-qth-data.h"
 #include "sat-pref-qth-editor.h"
 #include "locator.h"
+#include "compat.h"
 
 
 
@@ -100,7 +101,7 @@ static gboolean convert_qth_altitude (GtkTreeModel *model,
 /** \brief Create and initialise widgets for the locations prefs tab.
  *
  * The QTH tab consists of two main parts: A list showing the configured
- * locations (.qth files in $HOME/.gpredict2/ and three buttons beside the list:
+ * locations (.qth files in USER_CONF_DIR/ and three buttons beside the list:
  *    Add      Add a new location to the list
  *    Edit     Edit selected location
  *    Delete   Delete selected location
@@ -116,7 +117,6 @@ GtkWidget *sat_pref_qth_create ()
 {
 	
 	GtkWidget *vbox;    /* vbox containing the list part and the details part */
-	GtkWidget *qthlist;
 	GtkWidget *swin;
 
 
@@ -299,8 +299,7 @@ create_and_fill_model ()
 	/* scan for .qth files in the user config directory and
 	   add the contents of each .qth file to the list store
 	*/
-	dirname = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-						   ".gpredict2", NULL);
+    dirname = get_user_conf_dir ();
 	dir = g_dir_open (dirname, 0, &error);
 
 
@@ -381,7 +380,7 @@ read_qth_file (GtkListStore *liststore, gchar *filename)
 	}
 
 	/* read data from file */
-	if (!gtk_sat_data_read_qth (filename, qth)) {
+    if (!qth_data_read (filename, qth)) {
 		g_free (qth);
 		return FALSE;
 	}
@@ -455,7 +454,7 @@ read_qth_file (GtkListStore *liststore, gchar *filename)
 	g_free (fname);
 
 	/* we are finished with this qth, free it */
-	gtk_sat_data_free_qth (qth);
+    qth_data_free (qth);
 
 	return TRUE;
 }
@@ -559,7 +558,7 @@ delete_cb (GtkWidget *button, gpointer data)
 										 GTK_BUTTONS_OK,
 										 _("Can not delete ground station!\n\n"\
 										   "You need to have at least one ground\n"\
-										   "statiob set up, otherwise gpredict may\n"\
+										   "station set up, otherwise gpredict may\n"\
 										   "not work properly."));
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
@@ -825,8 +824,8 @@ save_qth (GtkTreeModel *model,
 		  gpointer      data)
 {
 	qth_t     qth;
-	gboolean  def     = FALSE;
-	gchar    *filename;
+    gboolean  def = FALSE;
+    gchar    *filename,*confdir;
 	gchar    *buff;
 
 
@@ -841,13 +840,9 @@ save_qth (GtkTreeModel *model,
 						QTH_LIST_COL_WX, &qth.wx,
 						-1);
 
-	filename = g_strconcat (g_get_home_dir (),
-							G_DIR_SEPARATOR_S,
-							".gpredict2",
-							G_DIR_SEPARATOR_S,
-							qth.name,
-							".qth",
-							NULL);
+    confdir = get_user_conf_dir ();
+    filename = g_strconcat (confdir, G_DIR_SEPARATOR_S,	qth.name, ".qth", NULL);
+    g_free (confdir);
 	
 	/* check wehter we are using imperial or metric system;
 	   in case of imperial we have to convert altitude from
@@ -857,7 +852,7 @@ save_qth (GtkTreeModel *model,
 		qth.alt = (guint) FT_TO_M(qth.alt);
 	}	
 	
-	if (gtk_sat_data_save_qth (filename, &qth)) {
+    if (qth_data_save (filename, &qth)) {
 		
 		/* saved ok, go on check whether qth is default */
 		if (def) {
@@ -901,8 +896,7 @@ delete_location_files ()
 	/* scan for .qth files in the user config directory and
 	   add the contents of each .qth file to the list store
 	*/
-	dirname = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-						   ".gpredict2", NULL);
+    dirname = get_user_conf_dir ();
 	dir = g_dir_open (dirname, 0, &error);
 
 
